@@ -1,4 +1,4 @@
-#    Copyright 2015 Province of British Columbia
+#    Copyright 2021 Province of British Columbia
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -13,7 +13,18 @@
 #    limitations under the License.
 
 #' @export
+stats::coef
+
+#' Turn a fitdists Object into a Tidy Tibble
+#' 
+#' A wrapper on [`tidy.fitdists()`].
+#' 
+#' @inheritParams params
+#' @seealso [`tidy.fitdists()`]
+#' @export
+#' @examples 
+#' fits <- ssd_fit_dists(ssddata::ccme_boron)
+#' coef(fits)
 coef.fitdists <- function(object, ...) {
-  coef <- lapply(object, coef, ...)
-  coef
+  tidy(object, ...)
 }
